Exception: HermesAgent::Client::Error

Inherits:
StandardError
  • Object
show all
Defined in:
lib/hermes_agent/client/errors.rb

Overview

Base class for all errors raised by the client. Rescue this to catch every failure mode the client can produce.